===============================
binarymap
===============================

.. image:: https://img.shields.io/pypi/v/binarymap.svg
        :target: https://pypi.python.org/pypi/binarymap

.. image:: https://app.travis-ci.com/jbloomlab/binarymap.svg
        :target: https://app.travis-ci.com/github/jbloomlab/binarymap

Bbinary representation of protein or nucleotide sequences.

``binarymap`` is a Python package written by `the Bloom lab <https://research.fhcrc.org/bloom/en.html>`_.

The source code is `on GitHub <https://github.com/jbloomlab/binarymap>`_.

See the `binarymap documentation <https://jbloomlab.github.io/binarymap>`_ for details on how to install and use ``binarymap``.

To contribute to this package, read the instructions in `CONTRIBUTING.rst <CONTRIBUTING.rst>`_.
